#!/usr/bin/env python3

import os
import shutil
import sys
import uuid


INTERMEDIATE = "divx2pass.log"

PASS1 = (
    "mencoder {inputfile!r} -oac mp3lame -lameopts vol=2:preset=128 -ovc lavc "
    "-lavcopts vcodec=mpeg4:vbitrate=9000:vpass=1:turbo -ni -o {outputile!r}"
)
PASS2 = (
    "mencoder {inputfile!r} -oac mp3lame -lameopts vol=2:preset=128 -ovc lavc "
    "-lavcopts vcodec=mpeg4:vbitrate=9000:vpass=2:vme=4:dia=2:mbd=1:v4mv:"
    "lumi_mask=0.3:dark_mask=0.3:ilme:last_pred=50:nr=500 -o {outputile!r}"
)

def main(inp_fname):
    out_fname = inp_fname[:-4] + ".avi"
    tmp_fname = inp_fname + "." + str(uuid.uuid4())

    # assure env is ok
    print("\nStart processing, inp={!r} tmp={!r} out={!r}".format(
        inp_fname, tmp_fname, out_fname))
    assert os.path.exists(inp_fname)
    assert not os.path.exists(INTERMEDIATE)
    if not inp_fname.endswith(".avi"):
        assert not os.path.exists(out_fname)

    # first pass
    print("Mencoder, first pass")
    cmd = PASS1.format(inputfile=inp_fname, outputile=tmp_fname)
    status = os.system(cmd)
    if status != 0:
        print("ERROR, status:", status)
        exit()

    # second pass
    print("Mencoder, second pass")
    cmd = PASS2.format(inputfile=inp_fname, outputile=tmp_fname)
    status = os.system(cmd)
    if status != 0:
        print("ERROR, status:", status)
        exit()

    # move stuff around
    print("Moving stuff around")
    if inp_fname.endswith(".avi"):
        # original file has the same name of ultimate destiny, just move
        shutil.move(tmp_fname, out_fname)
    else:
        shutil.move(tmp_fname, out_fname)
        os.remove(inp_fname)
    os.remove(INTERMEDIATE)

    print("Done")


if __name__ == '__main__':
    def die():
        print("Usage: {} input [input [...]]".format(sys.argv[0]))
        exit()

    if len(sys.argv) < 2:
        die()

    for fname in sys.argv[1:]:
        main(fname)
